Changelog
=========

1.3.1
-----

* Fixed graph command (hvdklauw)

1.3.0
-----

* Added graph command for graphing the migration dependency tree (hvdklauw)

1.2.4
-----

* Initial public release (bubenkoff)
